read_case_phases

Function read_case_phases 

fn read_case_phases(
    case_dir: &Path,
) -> Result<(RawPhase, Option<RawPhase>, [u32; 3]), CMError>
Read the phases of a case directory, gas being None when the case does not declare one